@@ -9,6 +9,7 @@
 import jsonpath_rw_ext as jp
 import codecs
 import json
+from requests import exceptions
 # import sys
 # reload(sys)
 # sys.setdefaultencoding('UTF-8')
@@ -66,6 +67,9 @@ def send_post_raw_method(url, params, cookies):
 
 # 接口请求逻辑相关代码
 def assemble_request(request_method, request_url, params_get, cookies):
+    req_post = ''
+    req_get = ''
+
     try:
         if request_method == 'GET':
             if params_get != {}:
@@ -83,19 +87,23 @@ def assemble_request(request_method, request_url, params_get, cookies):
                 return req_post
     except exceptions.Timeout as e:
         if request_method == 'POST':
-            req_post = '{ "data":' + str(req_post.text) + \
-                ',"msg":"接口响应错误","status":' + str(req_post.status_code) + '}'
+            req_post = '{ "data":' + str(req_post) + \
+                ',"msg":"接口响应错误","status":' + str("error") + '}'
+            return req_post
         if request_method == 'GET':
-            req_get = '{ "data":' + str(req_get.text) + \
-                ',"msg":"接口响应错误","status":' + str(req_get.status_code) + '}'
+            req_get = '{ "data":' + str(req_get) + \
+                ',"msg":"接口响应错误","status":' + str("error") + '}'
+            return req_get
         print(str(e))
     except Exception as e:
         if request_method == 'POST':
-            req_post = '{ "data":' + str(req_post.text) + \
-                ',"msg":"接口响应错误","status":' + str(req_post.status_code) + '}'
+            req_post = '{ "data":' + str(req_post) + \
+                ',"msg":"接口响应错误","status":' + str("error") + '}'
+            return req_post
         if request_method == 'GET':
-            req_get = '{ "data":' + str(req_get.text) + \
-                ',"msg":"接口响应错误","status":' + str(req_get.status_code) + '}'
+            req_get = '{ "data":' + str(req_get) + \
+                ',"msg":"接口响应错误","status":' + str("error") + '}'
+            return req_get
         print(e)
 
 
@@ -163,7 +171,7 @@ def assemble_params_formdata(request_method, request_url, request_formdata, para
     request_result_url = []
     params_get_child = {}
     params_get_list.append(str('{}'))
-    result = send_post_raw_method(request_url, {}, cookies)
+    result = assemble_request(request_method, request_url, {}, cookies)
     request_result_list.append(result)
     request_result_url.append(request_url + "\n\t请求方法:" + request_method)
     if len(request_formdata) > 0:
@@ -185,7 +193,7 @@ def assemble_params_formdata(request_method, request_url, request_formdata, para
                 result = ''
     else:
         params_get_list.append(str('{}'))
-        result = send_post_raw_method(request_url, {}, cookies)
+        result = assemble_request(request_method, request_url, {}, cookies)
         request_result_list.append(result)
         request_result_url.append(request_url + "\n\t请求方法:" + request_method)
 
@@ -221,26 +229,28 @@ def assemble_params_raw_other(request_method, request_url, request_raw, params_y
     request_result_list = []
     params_get = {}
     params_get_list = []
+    child_json = {}
     params_test = read_yaml(params_yaml)
     cookies = get_cookie(phone_cookie_yaml)
     request_result_url = []
     params_get_child = {}
     params_get_list.append(str('{}'))
-    result = send_post_raw_method(request_url, {}, cookies)
+    result = assemble_request(request_method, request_url, {}, cookies)
     request_result_list.append(result)
     request_result_url.append(request_url + "\n\t请求方法:" + request_method)
     if len(request_raw) > 0:
         for params_index in range(0, len(params_test)):
             params_get.clear()
+            child_json.clear()
             # 字典需要copy(),否则clear影响原字典
             params_get = request_raw.copy()
-            print("*******************************")
-            print(params_get)
+            # print(type(params_get))
             child_json = check_json_value(
                 params_get, str(params_test[params_index]))
 
-            # print(params_get)
-            result = send_post_raw_method(request_url, child_json, cookies)
+            # print(child_json)
+            result = assemble_request(
+                request_method, request_url, child_json, cookies)
             params_get_list.append(str(child_json))
             request_result_url.append(
                 request_url + "\n\t请求方法:" + request_method)
@@ -248,7 +258,7 @@ def assemble_params_raw_other(request_method, request_url, request_raw, params_y
             result = ''
     else:
         params_get_list.append(str('{}'))
-        result = send_post_raw_method(request_url, {}, cookies)
+        result = assemble_request(request_method, request_url, {}, cookies)
         request_result_list.append(result)
         request_result_url.append(request_url + "\n\t请求方法:" + request_method)
 
@@ -259,17 +269,14 @@ def assemble_params_raw_other(request_method, request_url, request_raw, params_y
 
 def check_json_value(dic_json, v):
     if isinstance(dic_json, dict):
-        print("&&&&&&&&&&&&&&&&&&&&&&&")
         for key in dic_json:
-            print(type(dic_json[key]))
-            print(dic_json[key])
-            if isinstance(type(dic_json[key]), str) and '{' in dic_json[key]:
+            if isinstance(type(dic_json[key]), str) or '{' in dic_json[key]:
                 dic_json[key] = eval(dic_json[key])
-            if key != 'method' and key != 'params':
+            if key != 'method' and key != 'params' and key != 'hashcode':
                 dic_json[key] = v
             elif isinstance(dic_json[key], dict):
                 check_json_value(dic_json[key], v)
-
+    # print(dic_json)
     return dic_json
 
 
@@ -313,12 +320,13 @@ def listToJson(lst):
 
 # 接口响应结果响应处理
 def getGetReq(req):
+    print(req.status_code)
     if req.status_code == 200 and str(req.content, 'utf-8') != "":
         req = req.json()
         req = json.dumps(req, sort_keys=True, indent=2,
                          separators=(',', ': '), ensure_ascii=False)
     else:
-        req = '{ "data":' + str(req.text) + ',"msg":"接口响应错误","status":' + \
+        req = '{ "data":' + str(req.content, 'utf-8') + ',"msg":"接口响应错误","status":' + \
             str(req.status_code) + '}'
     return req
 
