@@ -13,7 +13,7 @@ import codecs
 import json
 import sys
 
-from fuzzyInject.interface_send import assemble_params
+from fuzzyInject.interface_send import assemble_params, assemble_params_raw_other, assemble_params_formdata
 from fuzzyInject.showData import covertToHtml, assemble_html
 
 # reload(sys)
@@ -53,14 +53,15 @@ def _decode_dict(data):
 params_get_list = []
 request_results_list = []
 result_urls = []
-
-
+final_results = []
+result_collections = []
 # 解析json文件 和报告数据组装
+
+
 def parse_json_file(json_file_parse, paramsFile, phone_cookie_yaml):
     names = jp.match("$.item[*].name", json_file_parse)
-    final_results = []
+
     request_results = []
-    result_collection = []
     for i in range(0, len(names)):
         request_method = jp.match(
             "$.item[" + str(i) + "].request.method", json_file_parse)[0]
@@ -83,36 +84,27 @@ def parse_json_file(json_file_parse, paramsFile, phone_cookie_yaml):
             "$.item[" + str(i) + "].request.body.raw", json_file_parse)
         if request_raw != []:
             date_json = json.loads(request_raw[0])
-            print(date_json)
-            request_result_list, param_get_list, request_result_url = interface_send.assemble_params_raw_other(
+            # print(date_json)
+            request_result_list, param_get_list, request_result_url = assemble_params_raw_other(
                 request_method, request_url, date_json, paramsFile, phone_cookie_yaml)
-            get_result_collect(request_result_list,
-                               param_get_list, request_result_url)
+            print(param_get_list)
+            final_results = get_result_collect(request_result_list,
+                                               param_get_list, request_result_url)
         if request_formdata != []:
-            print(request_formdata)
+            # print(request_formdata)
             # 避免重复覆盖
             request_query = []
-            request_result_list, param_get_list, request_result_url = interface_send.assemble_params_formdata(
+            request_result_list, param_get_list, request_result_url = assemble_params_formdata(
                 request_method, request_url, request_formdata, paramsFile, phone_cookie_yaml)
             print(param_get_list)
-            get_result_collect(request_result_list,
-                               param_get_list, request_result_url)
+            final_results = get_result_collect(request_result_list,
+                                               param_get_list, request_result_url)
         if request_query != []:
-            request_result_list, param_get_list, request_result_url = interface_send.assemble_params(
+            request_result_list, param_get_list, request_result_url = assemble_params(
                 request_method, request_url, request_query, request_formdata, paramsFile, phone_cookie_yaml)
-            get_result_collect(request_result_list,
-                               param_get_list, request_result_url)
-    for result_index in range(len(request_results_list)):
-        if request_results_list[result_index] is None:
-            return
-        if 'status' not in request_results_list[result_index] or '"status":500' in request_results_list[result_index]:
-            result_collection.append('FAIL')
-        else:
-            result_collection.append('SUCCESS')
-    final_results.append(result_urls)
-    final_results.append(request_results_list)
-    final_results.append(result_collection)
-    final_results.append(params_get_list)
+            final_results = get_result_collect(request_result_list,
+                                               param_get_list, request_result_url)
+
     return final_results
 
 
@@ -123,11 +115,26 @@ def get_result_collect(request_result_list, param_get_list, request_result_url):
             request_results_list.append(request_result_list[add_index])
             params_get_list.append(param_get_list[add_index])
             result_urls.append(request_result_url[add_index])
+            if request_result_list[add_index] is None:
+                result_collections.append('FAIL')
+                return
+            if 'status' not in request_result_list[add_index] or '"status":500' in request_results_list[add_index]:
+                result_collections.append('FAIL')
+            else:
+                result_collections.append(
+                    'SUCCESS')
+
+    final_results.append(result_urls)
+    final_results.append(request_results_list)
+    final_results.append(result_collections)
+    final_results.append(params_get_list)
 
     request_result_list = []
     param_get_list = []
     request_result_url = []
 
+    return final_results
+
 
 # 读取文件
 def read_json_file(json_file):
@@ -152,12 +159,11 @@ def excute_interface(file, paramsFile, phone_cookie_yaml):
     json_file_parse = read_json_file(json_file)
     final_results = parse_json_file(
         json_file_parse, paramsFile, phone_cookie_yaml)
-    html = showData.covertToHtml(final_results, name)
+    html = covertToHtml(final_results, name)
     if final_results is None:
-        count_name = '接口存在异常无结果输出'
         return
     count_name = '请求结果总计:' + str(len(final_results[0]))
-    html_file = showData.assemble_html(count_name, html, '')
+    html_file = assemble_html(count_name, html, '')
     write_html_file(html_file)
 
 
